from setuptools import setup

setup( name='ljvillarrealm_dsnd_probability'
      ,version='0.1'
      ,description='Gaussian & Binomial distributions'
      ,packages=['ljvillarrealm_dsnd_probability']
      ,author='ljvillarrealm'
      ,author_email='ljvillarrealm@fastmail.com'
      #,url='www.ljvillarrealm.com'
      ,zip_safe=False
     )
